package com.aitrainer.api.security

import com.aitrainer.api.ApiApplication
import com.aitrainer.api.controller.ApplicationProperties
import com.aitrainer.api.controller.Singleton
import com.aitrainer.api.repository.ConfigurationRepository
import org.aspectj.lang.JoinPoint
import org.aspectj.lang.annotation.Aspect
import org.aspectj.lang.annotation.Before
import org.slf4j.LoggerFactory
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.stereotype.Component

@Suppress("unused")
@Aspect
@Component
class AuthenticationControllerAspect {
    private val logger = LoggerFactory.getLogger(ApiApplication::class.simpleName)

    @Autowired
    private lateinit var configurationRepository: ConfigurationRepository
    @Autowired
    private lateinit var properties: ApplicationProperties

    @Before("execution(* com.aitrainer.api.security.JwtAuthenticationController.*(..))")
    fun authControllerAspect(joinPoint: JoinPoint) {
        println("auth controller join")
        Singleton.checkDBUpdate(configurationRepository, properties)
    }

    @Before("execution(* com.aitrainer.api.security.JwtSecurityConfig.filterChain(..))")
    fun securityControllerAspect(joinPoint: JoinPoint) {
        println("JwtSecurity FilterChain config join")
        Singleton.checkDBUpdate(configurationRepository, properties)
    }

    @Before("execution(* com.aitrainer.api.security.JwtSecurityConfig.corsMappingConfigurer(..))")
    fun corsControllerAspect(joinPoint: JoinPoint) {
        println("JwtSecurity CorsMapper config join")
        Singleton.checkDBUpdate(configurationRepository, properties)
    }

   /* @Before("execution(* com.aitrainer.api.security.JwtRequestFilter.doFilterInternal(..))")
    fun requestFilterAspect(joinPoint: JoinPoint) {
        println("JwtRequestFilter join")
        Singleton.checkDBUpdate(configurationRepository, properties)
    }*/

}
