package com.aitrainer.api.test

import com.aitrainer.api.controller.ExercisePlanController
import com.aitrainer.api.controller.ExercisePlanDetailController
import com.aitrainer.api.model.ExercisePlan
import com.aitrainer.api.model.ExercisePlanDetail
import com.aitrainer.api.repository.ExercisePlanDetailRepository
import com.aitrainer.api.repository.ExercisePlanRepository
import org.junit.jupiter.api.Test
import org.junit.jupiter.api.TestInstance
import org.slf4j.LoggerFactory
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.boot.test.context.SpringBootTest
import org.springframework.http.HttpStatus
import org.springframework.http.ResponseEntity
import kotlin.test.assertEquals
import kotlin.test.assertNotNull

@SpringBootTest
@TestInstance(TestInstance.Lifecycle.PER_CLASS)
class ExercisePlanDetailTest {
    private val logger = LoggerFactory.getLogger(javaClass)

    @Autowired
    private lateinit var exercisePlanDetailRepository: ExercisePlanDetailRepository

    @Test
    fun testInsert() {
        val plan = ExercisePlan(

        )
        plan.exercisePlanId = 6

        val planDetail = ExercisePlanDetail(
                exerciseTypeId = 41,
                serie = 3,
                repeats = 12,
                weightEquation = "50",
                exercisePlanId = 6
        )
        val savedDetail: ExercisePlanDetail = exercisePlanDetailRepository.save(planDetail)
        assertEquals(savedDetail.repeats, 12)
        assertEquals(savedDetail.weightEquation, "50")
        exercisePlanDetailRepository.delete(savedDetail)
    }

 /*   @Test
    fun testGetLastExercisePlanDetail() {
        val exercisePlanDetailList: List<ExercisePlanDetail> = exercisePlanDetailRepository.getLastExercisePlanDetail(90)
        logger.info(" ****** list: $exercisePlanDetailList")
        assertEquals(exercisePlanDetailList.size, 2)

        val exercisePlanDetail: ExercisePlanDetail = exercisePlanDetailList[0]
        assertEquals(exercisePlanDetail.weightEquation, "40")
    } */

    @Test
    fun testUpdatePlanDetail() {
        val planDetail: ExercisePlanDetail = exercisePlanDetailRepository.findById(4).orElse(null)
        assertEquals(planDetail.exerciseTypeId, 39)
        assertEquals(planDetail.serie, 3)
        planDetail.weightEquation = "50%"
        planDetail.repeats = 30


        val planDetailController = ExercisePlanDetailController(exercisePlanDetailRepository)
        val response: ResponseEntity<*> = planDetailController.updateExercisePlanDetailById(4, planDetail, null)
        val updatedPlanDetail = response.body as ExercisePlanDetail
        assertEquals(planDetail.weightEquation, "50%")
        assertEquals(planDetail.repeats, 30)
        //assertEquals(planDetail.exercisePlan, )
        assertEquals(planDetail.exercisePlanDetailId, 4)

        updatedPlanDetail.weightEquation = "40"
        updatedPlanDetail.repeats = 1
        planDetailController.updateExercisePlanDetailById(4, updatedPlanDetail, null)
    }

    @Test
    fun testDeletePlanDetail() {
        val plan = ExercisePlan(

        )
        plan.exercisePlanId = 6

        val planDetail = ExercisePlanDetail(
                exerciseTypeId = 63,
                serie = 3,
                repeats = 120,
                weightEquation = "90",
                exercisePlanId = 6
        )
        val savedDetail: ExercisePlanDetail = exercisePlanDetailRepository.save(planDetail)
        assertEquals(savedDetail.weightEquation, "90")
        val newPlanDetailId = savedDetail.exercisePlanDetailId
        print(" --- new plan for delete $newPlanDetailId")

        val planDetailController = ExercisePlanDetailController(exercisePlanDetailRepository)

        val planDetailToDelete: ExercisePlanDetail = exercisePlanDetailRepository.findById(newPlanDetailId).orElse(null)
        assertNotNull(planDetailToDelete)

        val response: ResponseEntity<*> = planDetailController.deleteExercisePlanDetailById(newPlanDetailId)
        assertEquals(response.statusCode, HttpStatus.OK)

        val response2: ResponseEntity<*> = planDetailController.deleteExercisePlanDetailById(9999)
        assertEquals(response2.statusCode, HttpStatus.NOT_FOUND)

    }

    @Test
    fun testGetExercisePlanDetailByPlanId() {
        val exercisePlanDetailList: List<ExercisePlanDetail> = exercisePlanDetailRepository.findByExercisePlanId(6)
        logger.info(" ****** list: $exercisePlanDetailList")
        assertEquals(exercisePlanDetailList.size, 2)

        val exercisePlanDetail: ExercisePlanDetail = exercisePlanDetailList[0]
        assertEquals(exercisePlanDetail.repeats, 1)
    }
}

