package com.aitrainer.api.test

import com.aitrainer.api.controller.ExerciseController
import com.aitrainer.api.model.Exercises
import com.aitrainer.api.repository.ExercisesRepository
import org.junit.jupiter.api.Test
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.boot.test.context.SpringBootTest
import org.springframework.http.HttpStatus
import org.springframework.http.ResponseEntity
import kotlin.test.assertEquals
import kotlin.test.assertTrue

@SpringBootTest
class ExerciseTest {

    @Autowired
    private lateinit var exerciseRepository: ExercisesRepository

    @Test
    fun testGet() {
        var id: Long = 1

        val exercises: List<Exercises> = exerciseRepository.getAllByCustomerIdOrderByDateAddDesc( id )
        assertEquals( exercises[0].quantity, 30.0)

        id = 100000
        val exercises2: List<Exercises> = exerciseRepository.getAllByCustomerIdOrderByDateAddDesc( id )

        assertEquals( exercises2.size, 0)
    }

    @Test
    fun testGetByExerciseTypeId() {
        val id: Long = 2
        val exerciseController = ExerciseController(exerciseRepository)
        val response: ResponseEntity<List<Exercises>> = exerciseController.getAllExercisesByExerciseTypeId(id)

        val exercises = response.body

        assertTrue(exercises is List)
        assertTrue(exercises.isNotEmpty())
        assertEquals(exercises.size, 3)
        assertEquals(exercises[2].customerId, 90)

        val response2: ResponseEntity<List<Exercises>> = exerciseController.getAllExercisesByExerciseTypeId(22)
        assertEquals(response2.statusCode, HttpStatus.NOT_FOUND)
    }

    @Test
    fun testInsert() {
        var exercise = Exercises(
            exerciseTypeId = 3,
            customerId = 11,
            quantity = 100.0,
            dateAdd = "2020-05-13 04:32:00",
            unit = "repeat",
            unitQuantity = 30.0,
            restTime = null
        )
        var exerciseNew = exerciseRepository.save(exercise)
        assertTrue(exerciseNew.exerciseId > 2)
        exerciseRepository.delete(exercise)

        exercise = Exercises(
                exerciseTypeId = 40,
                customerId = 11,
                quantity = 32.5,
                dateAdd = "2020-07-05 04:32:00",
                unit = "repeat",
                unitQuantity = 32.6,
                restTime = null,
                exercisePlanDetailId = 6
        )
        exerciseNew = exerciseRepository.save(exercise)
        assertTrue(exerciseNew.exerciseId > 3)
        assertEquals(exerciseNew.exercisePlanDetailId, 6)
        exerciseRepository.delete(exercise)
    }

    @Test
    fun testDelete() {
        val exercise = Exercises(
                exerciseTypeId = 30,
                customerId = 11,
                quantity = 100.0,
                dateAdd = "2020-10-13 04:32:00",
                unit = "repeat",
                unitQuantity = 35.0,
                restTime = null
        )
        val exerciseNew = exerciseRepository.save(exercise)
        assertTrue(exerciseNew.exerciseId > 5)
        val newId = exerciseNew.exerciseId
        print("NewId for delete: $newId")

        val exerciseController = ExerciseController(exerciseRepository)
        val response: ResponseEntity<Exercises> = exerciseController.getExerciseById(newId)
        assertEquals(response.statusCode, HttpStatus.OK)

        val status: HttpStatus = exerciseController.deleteExerciseById(newId)
        assertEquals(status, HttpStatus.OK)

        val response2: ResponseEntity<Exercises> = exerciseController.getExerciseById(newId)
        assertEquals(response2.statusCode, HttpStatus.NOT_FOUND)

    }
}